
# Influence: The Psychology of Persuasion (Collins Business Essentials)

Authors: **Cialdini PhD, Robert B.**

## Influence The Psychology of Persuasion

## INTRODUCTION

The principles-consistency, reciprocation, social proof, authority, liking, and scarcity-are each discussed in terms of their function in the society and in terms of how their enormous force can be commissioned by a compliance professional

## Chapter 1 WEAPONS OF INFLUENCE

> Everything should be made as simple as possible, but not simpler.

**NOTE**
: Albert Einstein #simplicity

For a mother turkey, a polecat is a natural enemy whose approach is to be greeted with squawking, pecking, clawing rage. Indeed, the experimenters found that even a stuffed model of a polecat, when drawn by a string toward a mother turkey, received an immediate and furious attack. When, however, the same stuffed replica carried inside it a small recorder that played the "cheep-cheep" sound of baby turkeys, the mother not only accepted the oncoming polecat but gathered it underneath her. When the machine was turned off, the polecat model again drew a vicious attack.

> A well-known principle of human behavior says that when we ask someone to do us a favor we will be more successful if we provide a reason. People simply like to have reasons for what they do.

**NOTE**
: #asking

our automatic tapes usually develop from psychological principles or stereotypes we have learned to accept.

There is a principle in human perception, the contrast principle, that affects the way we see the difference between two things that are presented one after another. Simply put, if the second item is fairly different from the first, we will tend to see it as more different than it actually is.

It is much more profitable for salespeople to present the expensive item first, not only because to fail to do so will lose the influence of the contrast principle; to fail to do so will also cause the principle to work actively against them. Presenting an inexpensive product first and following it with an expensive one will cause the expensive item to seem even more costly as a result-hardly a desirable consequence for most sales organizations.

## Chapter 2 RECIPROCATION

the rule for reciprocation. 7 The rule says that we should try to repay, in kind, what another person has provided us.

The noted archaeologist Richard Leakey ascribes the essence of what makes us human to the reciprocity system: "We are human because our ancestors learned to share their food and their skills in an honored network of obligation,"

closely examine an experiment performed by Professor Dennis Regan of Cornell University.

A subject who participated in the study found himself rating, along with another subject, the quality of some paintings as part of an experiment on "art appreciation." The other rater-we can call him Joe-was only posing as a fellow subject and was actually Dr. Regan's assistant. For our purposes, the experiment took place under two different conditions. In some cases, Joe did a small, unsolicited favor for the true subject. During a short rest period, he left the room for a couple of minutes and returned with two bottles of Coca-Cola, one for the subject and one for himself, saying, "I asked him [the experimenter] if I could get myself a Coke, and he said it was okay, so I bought one for you, too." In other cases, Joe did not provide the subject with a favor; he simply returned from the two-minute break empty-handed. In all other respects, however, Joe behaved identically. Later on, after the paintings had all been rated and the experimenter had momentarily left the room, Joe asked the subject to do him a favor. He indicated that he was selling raffle tickets for a new car and that if he sold the most tickets, he would win a fifty-dollar prize. Joe's request was for the subject to buy some raffle tickets at twenty-five cents apiece: "Any would help, the more the better." The major finding of the study concerns the number of tickets subjects purchased from Joe under the two conditions. Without question, Joe was more successful in selling his raffle tickets to the subjects who had received his earlier favor. Apparently feeling that they owed him something, these subjects bought twice as many tickets as the subjects who had not been given the prior favor.

The interesting thing about the Regan experiment, however, is that the relationship between liking and compliance was completely wiped out in the condition under which subjects had been given a Coke by Joe. For those who owed him a favor, it made no difference whether they liked him or not; they felt a sense of obligation to repay him, and they did.

The Krishnas' resolution was brilliant. They switched to a fund-raising tactic that made it unnecessary for target persons to have positive feelings toward the fund-raisers. They began to employ a donation-request procedure that engaged the rule for reciprocation, which, as demonstrated by the Regan study, is strong enough to overcome the factor of dislike for the requester.

The unsuspecting passerby who suddenly finds a flower pressed into his hands or pinned to his jacket is under no circumstances allowed to give it back, even if he asserts that he does not want it. "No, it is our gift to you," says the solicitor, refusing to accept it. Only after the Krishna member has thus brought the force of the reciprocation rule to bear on the situation is the target asked to provide a contribution to the Society.

The beauty of the free sample, however, is that it is also a gift and, as such, can engage the reciprocity rule.

A favorite place for free samples is the supermarket, where customers are frequently provided with small cubes of a certain variety of cheese or meat to try. Many people find it difficult to accept a sample from the always-smiling attendant, return only the toothpick, and walk away. Instead, they buy some of the product, even if they might not have liked it especially well.

Another person can trigger a feeling of indebtedness by doing us an uninvited favor. Recall that the rule only states that we should provide to others the kind of actions they have provided us; it does not require us to have asked for what we have received in order to feel obligated to repay.

This is not to say that we might not feel a stronger sense of obligation to return a favor we have requested, only that such a request is not necessary to produce our indebtedness.

A person who violates the reciprocity rule by accepting without attempting to return the good acts of others is actively disliked by the social group. The exception, of course, is when the person is prevented from repayment by reasons of circumstance or ability. For the most part, however, there is a genuine distaste for individuals who fail to conform to the dictates of the reciprocity rule.

Another consequence of the rule, however, is an obligation to make a concession to someone who has made a concession to us.

The reciprocation rule brings about mutual concession in two ways. The first is obvious. It pressures the recipient of an already-made concession to respond in kind. The second, while not so obvious, is pivotally important. Just as in the case of favors, gifts, or aid, the obligation to reciprocate a concession encourages the creation of socially desirable arrangements by ensuring that anyone seeking to start such an arrangement will not be exploited.

Because the rule for reciprocation governs the compromise process, it is possible to use an initial concession as part of a highly effective compliance technique. The technique is a simple one that we can call the rejection-then-retreat technique. Suppose you want me to agree to a certain request. One way to increase your chances would be first to make a larger request of me, one that I will most likely turn down. Then, after I have refused, you would make the smaller request that you were really interested in all along.

The truly gifted negotiator, then, is one whose initial position is exaggerated enough to allow for a series of reciprocal concessions that will yield a desirable final offer from the opponent, yet is not so outlandish as to be seen as illegitimate from the start.

But what we have not yet examined is a little-known pair of positive by-products of the act of concession: feelings of greater responsibility for, and satisfaction with, the arrangement. It is this set of sweet side effects that enables the technique to move its victims to fulfill their agreements and to engage in further such agreements.

Responsibility. Those subjects facing the opponent who used the retreating strategy felt most responsible for the final deal. Much more than the subjects who faced a nonchanging negotiation opponent, these subjects reported that they had successfully influenced the opponent to take less money for himself. Of course, we know that they hadn't done any such thing. The experimenter had instructed their opponent to retreat gradually from his initial demand no matter what the subjects did. But it appeared to these subjects that they had made the opponent change, that they had produced his concessions. The result was that they felt more responsible for the final outcome of the negotiations. It does not require much of a leap from this finding to clarify the previous mystery of why the rejection-then-retreat technique causes its targets to live up to their agreements with such astounding frequency. The requester's concession within the technique not only causes targets to say yes more often, it also causes them to feel more responsible for having "dictated" the final agreement.

Satisfaction. Even though, on the average, they gave the most money to the opponent who used the concessions strategy, the subjects who were the targets of this strategy were the most satisfied with the final arrangement. It appears that an agreement that has been forged through the concessions of one's opponent is quite satisfying. With this in mind, we can begin to explain the second previously puzzling feature of the rejection-then-retreat tactic-the ability to prompt its victims to agree to further requests. Since the tactic uses a concession to bring about compliance, the victim is likely to feel more satisfied with the arrangement as a result. And it stands to reason that people who are satisfied with a given arrangement are more likely to be willing to agree to further such arrangements.

We will always encounter authentically generous individuals as well as many people who try to play fairly by the reciprocity rule rather than to exploit it.

## Chapter 3 COMMITMENT AND CONSISTENCY Hobgoblins of the Mind

It is easier to resist at the beginning than at the end. -LEONARDO DA VINCI

> Once we have made a choice or taken a stand, we will encounter personal and interpersonal pressures to behave consistently with that commitment. Those pressures will cause us to respond in ways that justify our earlier decision.

**NOTE**
: #decision #pride #bias

To understand why consistency is so powerful a motive, it is important to recognize that in most circumstances consistency is valued and adaptive. Inconsistency is commonly thought to be an undesirable personality trait. The person whose beliefs, words, and deeds don't match may be seen as indecisive, confused, two-faced, or even mentally ill. On the other side, a high degree of consistency is normally associated with personal and intellectual strength. It is at the heart of logic, rationality, stability, and honesty. A

several of the big toy companies jack up their January and February sales. They start prior to Christmas with attractive TV ads for certain special toys. The kids, naturally, want what they see and extract Christmas promises for these items from their parents. Now here's where the genius of the companies' plan comes in: They undersupply the stores with the toys they've gotten the parents to promise. Most parents find those things sold out and are forced to substitute other toys of equal value. The toy manufacturers, of course, make a point of supplying the stores with plenty of these substitutes. Then, after Christmas, the companies start running the ads again for the other, special toys. That juices up the kids to want those toys more than ever. They go running to their parents whining, ‘You promised, you promised,' and the adults go trudging off to the store to live up dutifully to their words."

If I can get you to make a commitment (that is, to take a stand, to go on record), I will have set the stage for your automatic and ill-considered consistency with that earlier commitment.

suppose you wanted to increase the number of people in your area who would agree to go door-to-door collecting donations for your favorite charity. You would be wise to study the approach taken by social psychologist Steven J. Sherman. He simply called a sample of Bloomington, Indiana, residents as part of a survey he was taking and asked them to predict what they would say if asked to spend three hours collecting money for the American Cancer Society. Of course, not wanting to seem uncharitable to the survey taker or to themselves, many of these people said that they would volunteer. The consequence of this sly commitment procedure was a 700 percent increase in volunteers when, a few days later, a representative of the American Cancer Society did call and ask for neighborhood canvassers. Using the same strategy, but this time asking Columbus, Ohio, residents to predict whether they would vote on Election Day, a team of researchers led by Anthony Greenwald were able to increase significantly the turnout in a U.S. presidential election among those called.

The tactic of starting with a little request in order to gain eventual compliance with related larger requests has a name: the foot-in-the-door technique.

What the Freedman and Fraser findings tell us, then, is to be very careful about agreeing to trivial requests. Such an agreement can not only increase our compliance with very similar, much larger requests, it can also make us more willing to perform a variety of larger favors that are only remotely connected to the little one we did earlier. It's this second, general kind of influence concealed within small commitments that scares me.

Notice that all of the foot-in-the-door experts seem to be excited about the same thing: You can use small commitments to manipulate a person's self-image; you can use them to turn citizens into "public servants," prospects into "customers," prisoners into "collaborators."

> Social scientists have determined that we accept inner responsibility for a behavior when we think we have chosen to perform it in the absence of strong outside pressures.

**NOTE**
: #responibility #decision

we should never heavily bribe or threaten our children to do the things we want them truly to believe in. Such pressures will probably produce temporary compliance with our wishes. However, if we want more than just that, if we want the children to believe in the correctness of what they have done, if we want them to continue to perform the desired behavior when we are not present to apply those outside pressures, then we must somehow arrange for them to accept inner responsibility for the actions we want them to take.

We need even that dangerous, mechanical brand of consistency. The only way out of the dilemma is to know when such consistency is likely to lead to a poor choice. There are certain signals-two separate kinds of signals, in fact-to tip us off. We register each type in a different part of our bodies.

The first sort of signal is easy to recognize. It occurs right in the pit of our stomachs when we realize we are trapped into complying with a request we know we don't want to perform.

I don't try to deny the importance of consistency; I just point out the absurdity of foolish consistency.

But our language does give it a name: heart of hearts. It is, by definition, the one place where we cannot fool ourselves. It is the place where none of our justifications, none of our rationalizations penetrate.

Accumulating psychological evidence indicates that we experience our feelings toward something a split second before we can intellectualize about it. 45 My suspicion is that the message sent by the heart of hearts is a pure, basic feeling. Therefore, if we train ourselves to be attentive, we should register it ever so slightly before our cognitive apparatus engages.

## Chapter 4 SOCIAL PROOF Truths Are Us

we first need to understand the nature of yet another potent weapon of influence: the principle of social proof. It states that one means we use to determine what is correct is to find out what other people think is correct. The principle applies especially to the way we decide what constitutes correct behavior. We view a behavior as more correct in a given situation to the degree that we see others performing it. Whether the question is what to do with an empty popcorn box in a movie theater, how fast to drive on a certain stretch of highway, or how to eat the chicken at a dinner party, the actions of those around us will be important in defining the answer.

remember how, consequently, it was possible to trick a female turkey into mothering a stuffed polecat as long as the replica played the recorded "cheep-cheep" of a baby turkey? The simulated chick sound was enough to start the female's mothering tape whirring.

Bartenders often "salt" their tip jars with a few dollar bills at the beginning of the evening to simulate tips left by prior customers and thereby to give the impression that tipping with folding money is proper barroom behavior.

an Arizona State University research team that infiltrated the Billy Graham organization reported on such advance preparations prior to one of his Crusade visits. "By the time Graham arrives in town and makes his altar call, an army of six thousand wait with instructions on when to come forth at varying intervals to create the impression of a spontaneous mass outpouring." 48

This, then, explains their sudden shift from secretive conspirators to zealous missionaries. And it explains the curious timing of the shift-precisely when a direct disconfirmation of their beliefs had rendered them least convincing to outsiders. It was necessary to risk the scorn and derision of the nonbelievers because publicity and recruitment efforts provided the only remaining hope. If they could spread the Word, if they could inform the uninformed, if they could persuade the skeptics, and if, by so doing, they could win new converts, their threatened but treasured beliefs would become truer. The principle of social proof says so: The greater the number of people who find any idea correct, the more the idea will be correct. The group's assignment was clear; since the physical evidence could not be changed, the social evidence had to be. Convince and ye shall be convinced! 52

> In general, when we are unsure of ourselves, when the situation is unclear or ambiguous, when uncertainty reigns, we are most likely to look to and accept the actions of others as correct.

**NOTE**
: #uncertainty #decision

A thorough understanding of the pluralistic ignorance phenomenon helps immeasurably to explain a regular occurrence in our country that has been termed both a riddle and a national disgrace: the failure of entire groups of bystanders to aid victims in agonizing need of help.

The second reason is the more psychologically intriguing one; it is founded on the principle of social proof and involves the pluralistic ignorance effect. Very often an emergency is not obviously an emergency. Is the man lying in the alley a heart-attack victim or a drunk sleeping one off? Are the sharp sounds from the street gunshots or truck backfires? Is the commotion next door an assault requiring the police or an especially loud marital spat where intervention would be inappropriate and unwelcome? What is going on? In times of such uncertainty, the natural tendency is to look around at the actions of others for clues. We can learn, from the way the other witnesses are reacting, whether the event is or is not an emergency.

the state of pluralistic ignorance "in which each person decides that since nobody is concerned, nothing is wrong. Meanwhile, the danger may be mounting to the point where a single individual, uninfluenced by the seeming calm of others, would react." 54

In their first experiment, a New York college student who appeared to be having an epileptic seizure received help 85 percent of the time when there was a single bystander present but only 31 percent of the time with five bystanders present.

single bystanders provided emergency aid 90 percent of the time, whereas such aid occurred in only 16 percent of the cases when a bystander was in the presence of two other bystanders who remained passive.

if the people in the group are strangers to one another. It seems that the pluralistic ignorance effect is strongest among strangers: Because we like to look poised and sophisticated in public and because we are unfamiliar with the reactions of those we do not know, we are unlikely to give off or correctly read expressions of concern when in a grouping of strangers. Therefore, a possible emergency becomes viewed as a nonemergency, and the victim suffers. 56

your best strategy when in need of emergency help is to reduce the uncertainties of those around you concerning your condition and their responsibilities. Be as precise as possible about your need for aid. Do not allow bystanders to come to their own conclusions because, especially in a crowd, the principle of social proof and the consequent pluralistic ignorance effect might well cause them to view your situation as a nonemergency. And request assistance of a single individual from the group of onlookers. Fight the natural tendency to make a general request for help.

> We will use the actions of others to decide on proper behavior for ourselves, especially when we view those others as similar to ourselves.

**NOTE**
: #decision #behaviour

> After a suicide has made front-page news, airplanes-private planes, corporate jets, airliners-begin falling out of the sky at an alarming rate. For example, it has been shown that immediately following certain kinds of highly publicized suicide stories, the number of people who die in commercial-airline crashes increases by 1,000 percent! Even more alarming: The increase is not limited to airplane deaths. The number of automobile fatalities shoots up as well. 58 What could possibly be responsible?

**NOTE**
: #suicide

The influence of suicide stories on car and plane crashes, then, is fantastically specific. Stories of pure suicides, in which only one person dies, generate wrecks in which only one person dies; stories of suicide-murder combinations, in which there are multiple deaths, generate wrecks in which there are multiple deaths.

It is Phillips's argument that certain troubled people who read of another's self-inflicted death kill themselves in imitation.

Phillips got his evidence for the modern-day Werther effect by examining the suicide statistics in the United States between 1947 and 1968. He found that within two months after every front-page suicide story, an average of fifty-eight more people than usual killed themselves.

the wider the publicity given the first suicide, the greater the number of later suicides.

For any of several reasons-to protect their reputations, to spare their families the shame and hurt, to allow their dependents to collect on insurance policies-they do not want to appear to have killed themselves. They would rather seem to have died accidentally. So, purposively but furtively, they cause the wreck of a car or a plane they are operating or are simply riding in. This could be accomplished in a variety of all-too-familiar-sounding ways. A commercial-airline pilot could dip the nose of the aircraft at a crucial point of takeoff or could inexplicably land on an already occupied runway against instructions from the control tower; the driver of a car could suddenly swerve into a tree or into oncoming traffic; a passenger in an automobile or corporate jet could incapacitate the operator, causing a deadly crash; the pilot of a private plane could, despite all radio warnings, plow into another aircraft.

> the most influential leaders are those who know how to arrange group conditions to allow the principle of social proof to work maximally in their favor.

**NOTE**
: #influence #leader

> we seem to assume that if a lot of people are doing the same thing, they must know something we don't. Especially when we are uncertain, we are willing to place an enormous amount of trust in the collective knowledge of the crowd.

**NOTE**
: #ignorance #doubt #belief

## Chapter 5 LIKING The Friendly Thief

all sorts of other compliance professionals recognize the pressure to say yes to someone we know and like. Take, for instance, the growing number of charity organizations that recruit volunteers to canvass for donations close to their own homes. They understand perfectly how much more difficult it is for us to turn down a charity request when it comes from a friend or a neighbor.

Once a customer admits to liking a product, he or she can be pressed for the names of friends who would also appreciate learning about it. The individuals on that list can then be approached for sales and a list of their friends, who can serve as sources for still other potential customers, and so on in an endless chain.

Although it is generally acknowledged that good-looking people have an advantage in social interaction, recent findings indicate that we may have sorely underestimated the size and reach of that advantage. There seems to be a click, whirr response to attractive people.

A halo effect occurs when one positive characteristic of a person dominates the way that person is viewed by others. And the evidence is now clear that physical attractiveness is often such a characteristic.

a study of the Canadian federal elections found that attractive candidates received more than two and a half times as many votes as unattractive candidates.

in hiring situations. In one study, good grooming of applicants in a simulated employment interview accounted for more favorable hiring decisions than did job qualifications-this, even though the interviewers claimed that appearance played a small role in their choices.

Good-looking people are likely to receive highly favorable treatment in the legal system. For example, in a Pennsylvania study, researchers rated the physical attractiveness of seventy-four separate male defendants at the start of their criminal trials. When, much later, the researchers checked court records for the results of these cases, they found that the handsome men had received significantly lighter sentences.

fashionable clothiers select their floor staffs from among the good-looking candidates, and that con men are handsome and con women pretty.

> We like people who are similar to us. This fact seems to hold true whether the similarity is in the area of opinions, personality traits, background, or life-style.

**NOTE**
: #friendship #relationship

I would advise special caution in the presence of requesters who claim to be "just like you." Indeed, it would be wise these days to be careful around salespeople who just seem to be just like you. Many sales training programs now urge trainees to "mirror and match" the customer's body posture, mood, and verbal style, as similarities along each of these dimensions have been shown to lead to positive results.

The crucial procedure was the experimenters' imposition of common goals on the groups. It was the cooperation required to achieve these goals that finally allowed the rival group members to experience one another as reasonable fellows, valued helpers, and friends. And when success resulted from the mutual efforts, it became especially difficult to maintain feelings of hostility toward those who had been teammates in the triumph.

The task, then, is not to eliminate academic competition but to break its monopoly in the classroom by introducing regular cooperative successes that include members of all ethnic groups.

when children of different racial groups are thrown into the incessant, harsh competition of the standard American classroom, we ought to see-and we do see-the worsening of hostilities. Second, the evidence that team-oriented learning is an antidote to this disorder may tell us about the heavy impact of cooperation on the liking process.

> "The nature of bad news," he said, "infects the teller." There is a natural human tendency to dislike a person who brings us unpleasant information, even when that person did not cause the bad news. The simple association with it is enough to stimulate our dislike.

**NOTE**
: #bias

The time to react protectively is when we feel ourselves liking the practitioner more than we should under the circumstances.

The recognition of that feeling can serve as our reminder to separate the dealer from the merits of the deal and to make our decision based on considerations related only to the latter.

## Chapter 6 AUTHORITY Directed Deference

A physician ordered ear drops to be administered to the right ear of a patient suffering pain and infection there. But instead of writing out completely the location "right ear" on the prescription, the doctor abbreviated it so that the instructions read "place in R ear." Upon receiving the prescription, the duty nurse promptly put the required number of ear drops into the patient's anus.

it is not necessarily the pleasantness of a thing that makes it seem bigger to us, it is its importance.

To twenty-two separate nurses' stations on various surgical, medical, pediatric, and psychiatric wards, one of the researchers made an identical phone call in which he identified himself as a hospital physician and directed the answering nurse to give twenty milligrams of a drug (Astrogen) to a specific ward patient. There were four excellent reasons for a nurse's caution in response to this order: (1) The prescription was transmitted by phone, in direct violation of hospital policy. (2) The medication itself was unauthorized; Astrogen had not been cleared for use nor placed on the ward stock list. (3) The prescribed dosage was obviously and dangerously excessive. The medication containers clearly stated that the "maximum daily dose" was only ten milligrams, half of what had been ordered. (4) The directive was given by a man the nurse had never met, seen, or even talked with before on the phone. Yet, in 95 percent of the instances, the nurses went straightaway to the ward medicine cabinet, where they secured the ordered dosage of Astrogen and started for the patient's room to administer it. It was at this point that they were stopped by a secret observer, who revealed the nature of the experiment.

Posing two questions to ourselves can help enormously to accomplish this trick. The first is to ask, when we are confronted with what appears to be an authority figure's influence attempt, "Is this authority truly an expert?"

By wondering how an expert stands to benefit from our compliance, we give ourselves another safety net against undue and automatic influence. Even knowledgeable authorities in a field will not persuade us until we are satisfied that their messages represent the facts faithfully.

Chapter 7 SCARCITY The Rule of the Few

The way to love anything is to realize that it might be lost. -G. K. CHESTERTON

Something that, on its own merits, held little appeal for me had become decidedly more attractive merely because it would soon become unavailable.

The drop from abundance to scarcity produced a decidedly more positive reaction to the cookies than did constant scarcity.

Freedoms once granted will not be relinquished without a fight.

Although the consequences of televised violence on the aggressive actions of children are far from simple, the data from a well-controlled experiment by psychologists Robert Liebert and Robert Baron (1972) have an ominous look. Some children were shown excerpts from a television program in which people intentionally harmed another. Afterward, these children were significantly more harmful toward another child than were children who had watched a nonviolent television program (a horserace). The finding that seeing others perform aggressively led to more aggression on the part of the young viewers held true for the two age groups tested (five-to-six-year-olds and eight-to-nine-year-olds) and for both girls and boys.

